import React from 'react';
import { View, Image, Text } from '@ray-js/components';
import clsx from 'clsx';

import res from './res';
import Strings from './i18n';
import AnnulusPickerColor from './component';
import styled from './index.module.less';
import { IProps } from './props';

const { ring } = res;
const LampCirclePicker = (props: IProps) => {
  const {
    value,
    temperature,
    radius,
    innerRingRadius,
    useEventChannel,
    eventChannelName,
    titleStyle,
    descStyle,
    style,
    onTouchStart,
    desc,
    onTouchMove,
    onTouchEnd,
    showInnerCircle = true,
    touchCircleLineWidth,
    touchCircleStrokeStyle,
  } = props;

  const innerImgRadius = innerRingRadius * 4 * 0.8;
  const _value = value ?? temperature;
  return (
    <View className={clsx(styled.container, styled.flexCenter)} style={style}>
      <AnnulusPickerColor
        value={_value}
        radius={radius}
        innerRingRadius={innerRingRadius}
        useEventChannel={useEventChannel || false}
        eventChannelName={eventChannelName}
        touchCircleLineWidth={touchCircleLineWidth}
        touchCircleStrokeStyle={touchCircleStrokeStyle}
        onTouchStart={onTouchStart}
        onTouchMove={onTouchMove}
        onTouchEnd={onTouchEnd}
      />

      <View className={clsx(styled.innerBox, styled.flexCenter)}>
        {showInnerCircle && (
          <Image
            src={ring}
            className={styled.ringIcon}
            style={{
              width: innerImgRadius,
              height: innerImgRadius,
            }}
          />
        )}
        <View className={clsx(styled.textBox, styled.flexCenter)}>
          <Text className={styled.title} style={titleStyle}>
            {Math.trunc(_value / 10)}%
          </Text>
          <Text className={styled.desc} style={descStyle}>
            {desc || Strings.getLang('temperature')}
          </Text>
        </View>
      </View>
    </View>
  );
};

const nilFn = () => null;
LampCirclePicker.defaultProps = {
  radius: 140,
  innerRingRadius: 80,
  useEventChannel: false,
  eventChannelName: 'lampCirclePickerEventChannel',
  titleStyle: {},
  descStyle: {},
  style: {},
  onTouchStart: nilFn,
  onTouchMove: nilFn,
  onTouchEnd: nilFn,
};

export default LampCirclePicker;
